@@ -16,6 +16,11 @@
 #include <stdlib.h>
 #include <string.h>
 
+/**
+ * The return code for skipped tests. Use the return code if the test should be skipped.
+ */
+#define AWS_OP_SKIP (-2)
+
 #ifndef AWS_UNSTABLE_TESTING_API
 #    error The AWS Test Fixture is designed only for use by AWS owned libraries for the AWS C99 SDK. You are welcome to use it,   \
 but you should be aware we make no promises on the stability of this API.  To enable use of the aws test fixtures, set \
@@ -26,12 +31,12 @@ the AWS_UNSTABLE_TESTING_API compiler flag
 #    define AWS_TESTING_REPORT_FD stderr
 #endif
 
-#if _MSC_VER
+#ifdef _MSC_VER
 #    pragma warning(disable : 4221) /* aggregate initializer using local variable addresses */
 #    pragma warning(disable : 4204) /* non-constant aggregate initializer */
 #endif
 
-/** Prints a message to stdout using printf format that appends the function, file and line number.
+/** Prints a message to AWS_TESTING_REPORT_FD using printf format that appends the function, file and line number.
  * If format is null, returns 0 without printing anything; otherwise returns 1.
  */
 static int s_cunit_failure_message0(
@@ -52,7 +57,7 @@ static int s_cunit_failure_message0(
     vfprintf(AWS_TESTING_REPORT_FD, format, ap);
     va_end(ap);
 
-    fprintf(AWS_TESTING_REPORT_FD, " [%s():%s@#%d]\n", function, file, line);
+    fprintf(AWS_TESTING_REPORT_FD, " [%s(): %s:%d]\n", function, file, line);
 
     return 1;
 }
@@ -62,9 +67,26 @@ static int s_cunit_failure_message0(
     s_cunit_failure_message0(FAIL_PREFIX, func, file, line, format, #__VA_ARGS__)
 
 static int total_failures;
+static int total_skip;
 
 #define SUCCESS (0)
 #define FAILURE (-1)
+/* The skip code returned to ctest to indicate the test is skipped. Refer to cmake doc:
+ * https://cmake.org/cmake/help/latest/prop_test/SKIP_RETURN_CODE.html */
+#define SKIP (1)
+
+#define POSTSKIP_INTERNAL()                                                                                            \
+    do {                                                                                                               \
+        total_skip++;                                                                                                  \
+        return SKIP;                                                                                                   \
+    } while (0)
+
+#define RETURN_SKIP(format, ...)                                                                                       \
+    do {                                                                                                               \
+        printf(format, ##__VA_ARGS__);                                                                                 \
+        printf("\n");                                                                                                  \
+        POSTSKIP_INTERNAL();                                                                                           \
+    } while (0)
 
 #define RETURN_SUCCESS(format, ...)                                                                                    \
     do {                                                                                                               \
@@ -434,30 +456,36 @@ static inline int s_aws_run_test_case(struct aws_test_harness *harness) {
         test_res |= harness->on_after(allocator, setup_res, harness->ctx);
     }
 
-    if (!test_res) {
-        if (!harness->suppress_memcheck) {
-            /* Reset the logger as test can set their own logger and clean it up. */
-            aws_logger_set(&err_logger);
-            const size_t leaked_bytes = aws_mem_tracer_count(allocator);
-            if (leaked_bytes) {
-                aws_mem_tracer_dump(allocator);
-            }
-            ASSERT_UINT_EQUALS(0, aws_mem_tracer_count(allocator));
-        }
+    if (test_res != AWS_OP_SUCCESS && test_res != AWS_OP_SKIP) {
+        goto fail;
     }
 
-    /* clean up */
     if (!harness->suppress_memcheck) {
+        /* Reset the logger, as test can set their own logger and clean it up,
+         * but aws_mem_tracer_dump() needs a valid logger to be active */
+        aws_logger_set(&err_logger);
+
+        const size_t leaked_bytes = aws_mem_tracer_count(allocator);
+        if (leaked_bytes) {
+            aws_mem_tracer_dump(allocator);
+            PRINT_FAIL_INTERNAL0("Test leaked memory: %zu bytes", leaked_bytes);
+            goto fail;
+        }
+
         aws_mem_tracer_destroy(allocator);
     }
+
     aws_logger_set(NULL);
     aws_logger_clean_up(&err_logger);
 
-    if (!test_res) {
+    if (test_res == AWS_OP_SUCCESS) {
         RETURN_SUCCESS("%s [ \033[32mOK\033[0m ]", harness->test_name);
-    } else {
-        FAIL("%s [ \033[31mFAILED\033[0m ]", harness->test_name);
+    } else if (test_res == AWS_OP_SKIP) {
+        RETURN_SKIP("%s [ \033[32mSKIP\033[0m ]", harness->test_name);
     }
+
+fail:
+    FAIL("%s [ \033[31mFAILED\033[0m ]", harness->test_name);
 }
 
 /* Enables terminal escape sequences for text coloring on Windows. */
